import { dirname, resolve } from "path";
import pkg from "fs-extra";
import { appIndexTsTemplate } from "./templates/src/ui/index.tsx.template.js";
import { appTemplate } from "./templates/src/ui/App.tsx.template.js";
import { indexCssTemplate } from "./templates/src/ui/index.css.template.js";
import { trpcClientTemplate } from "./templates/src/ui/trpc.ts.template.js";
import { siteConfigurationSurfaceTemplate } from "./templates/src/ui/surfaces/SiteConfiguration.tsx.template.js";
import { trpcFunctionTemplate } from "./templates/src/functions/trpc.ts.template.js";
import { trpcServerRouterTemplate } from "./templates/src/server/router.ts.template.js";
import { serverTrpcTemplate } from "./templates/src/server/trpc.ts.template.js";
import { indexHtmlTemplate } from "./templates/src/ui/index.html.js";
import { tailwindConfigTsTemplate } from "./templates/tailwind.config.ts.template.js";
import {
  tsconfigBackendJsonTemplate,
  tsconfigJsonTemplate,
  tsconfigUiJsonTemplate,
} from "./templates/tsconfig.json.template.js";
import { viteConfigTemplate } from "./templates/vite.config.ts.template.js";
import { netlifyTomlTemplate } from "./templates/netlify.toml.template.js";
import { teamConfigurationSurfaceTemplate } from "./templates/src/ui/surfaces/TeamConfiguration.tsx.template.js";
import { BOILERPLATE_OPTIONS } from "../constants.js";
import { connectConfigurationSurfaceTemplate } from "./templates/src/ui/surfaces/ConnectConfiguration.tsx.template.js";
import { teamSettingsSchemaTemplate } from "./templates/src/schema/team-settings-schema.ts.template.js";

const { ensureDirSync, writeFileSync } = pkg;

export const extensionUIDeps = [
  "@netlify/functions@latest",
  // "@netlify/sdk@2.0.0-pre.21b39c9", // todo: fix the vendored file install error & update to latest version on release
  "react@latest",
  "react-dom@latest",

  "@trpc/client@11.0.0-rc.477", // todo: make sure we are using the same version as @netlify/sdk--ui-functions (preferably the latest supported version)
  "@trpc/server@11.0.0-rc.477", // ! should be same version as `@trpc/client` and `@trpc/react-query`
  "@trpc/react-query@11.0.0-rc.477", // ! should be same version as `@trpc/client` and `@trpc/react-query`

  "@tanstack/react-query@latest",
  "zod@latest",
];

export const extensionUIDevDeps = [
  "@types/react@latest",
  "@types/react-dom@latest",
  "@tsconfig/recommended@latest",
  "@tsconfig/strictest@latest",
  "@tsconfig/vite-react@latest",
  "@vitejs/plugin-react@latest",
  "vite@latest",
  "autoprefixer@latest",
  "tailwindcss@latest",

  "@netlify/netlify-plugin-netlify-extension@0.2.0-pre.2e2310c", // todo: update to latest version on release
];

export const generateUiBoilerplate = (
  destination: string,
  boilerplate: string[],
) => {
  const hasConnectorBoilerplate = boilerplate.includes(
    BOILERPLATE_OPTIONS.connector,
  );
  const files: Record<string, string> = {
    "netlify.toml": netlifyTomlTemplate,
    "src/ui/index.html": indexHtmlTemplate,
    "src/ui/index.tsx": appIndexTsTemplate,
    "src/ui/App.tsx": appTemplate(boilerplate),
    "src/ui/index.css": indexCssTemplate,
    "src/ui/trpc.ts": trpcClientTemplate,
    "src/schema/team-settings-schema.ts": teamSettingsSchemaTemplate,
    "src/ui/surfaces/SiteConfiguration.tsx": siteConfigurationSurfaceTemplate,
    "src/ui/surfaces/TeamConfiguration.tsx": teamConfigurationSurfaceTemplate,
    "src/functions/trpc.ts": trpcFunctionTemplate,
    "src/server/trpc.ts": serverTrpcTemplate,
    "src/server/router.ts": trpcServerRouterTemplate,
    "tailwind.config.ts": tailwindConfigTsTemplate,
    "tsconfig.json": tsconfigJsonTemplate,
    "tsconfig.ui.json": tsconfigUiJsonTemplate,
    "tsconfig.backend.json": tsconfigBackendJsonTemplate,
    "vite.config.ts": viteConfigTemplate,
  };

  if (hasConnectorBoilerplate) {
    files["src/ui/surfaces/ConnectConfiguration.tsx"] =
      connectConfigurationSurfaceTemplate;
  }

  for (const [file, content] of Object.entries(files)) {
    const dir = dirname(resolve(destination, file));
    ensureDirSync(resolve(destination, dir));
    writeFileSync(resolve(destination, file), content);
  }
};
