import { BOILERPLATE_OPTIONS } from "../../../../constants.js";

export const appTemplate = (boilerplate: string[]) => {
  const hasConnectorBoilerplate = boilerplate.includes(
    BOILERPLATE_OPTIONS.connector,
  );

  return `import { useMemo, useState } from "react";
import { Surfaces } from "@netlify/sdk/ui";
import { useNetlifySDK } from "@netlify/sdk/ui/react";
import { httpBatchLink } from "@trpc/client";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { trpc } from "./trpc.js";
import { SiteConfiguration } from "./surfaces/SiteConfiguration.jsx";
import { TeamConfiguration } from "./surfaces/TeamConfiguration.js";
${hasConnectorBoilerplate ? `import { ConnectConfiguration } from "./surfaces/ConnectConfiguration.js";` : ``}

const surfaceToComponent = new Map([
  [Surfaces.SiteConfiguration, SiteConfiguration],
  [Surfaces.TeamConfiguration, TeamConfiguration],${
    hasConnectorBoilerplate
      ? `
  [Surfaces.ConnectConfiguration, ConnectConfiguration],`
      : ``
  }
]);

export const App = () => {
  const sdk = useNetlifySDK();
  const [queryClient] = useState(() => new QueryClient());
  const [trpcClient] = useState(() =>
    trpc.createClient({
      links: [
        httpBatchLink({
          url: "/api/trpc",
          headers: () => ({
            "Nf-UIExt-Extension-Slug": sdk.extension.slug,
            "Nf-UIExt-Netlify-Token":
              sdk.context.auth.netlifyToken ?? undefined,
            "Nf-UIExt-Provider-Token":
              sdk.context.auth.providerToken ?? undefined,
            "Nf-UIExt-Site-Id": sdk.context.siteId ?? undefined,
            "Nf-UIExt-Team-Id": sdk.context.teamId ?? undefined,
          }),
        }),
      ],
    })
  );

  const Component = useMemo(() => {
    for (const [surface, Component] of surfaceToComponent.entries()) {
      if (sdk.surface.is(surface)) {
        return Component;
      }
    }
    return null;
  }, [sdk.surface]);

  return (
    <>
      <trpc.Provider client={trpcClient} queryClient={queryClient}>
        <QueryClientProvider client={queryClient}>
          {Component !== null ? <Component /> : null}
        </QueryClientProvider>
      </trpc.Provider>
    </>
  );
};
`;
};
